@@ -9,21 +9,21 @@
 // or else upgrading old project file will not work
 // reliably.
 // TODO QGIS 4: remove in favor of _QGIS_VERSION
-#define VERSION "3.42.3-Münster"
-#define _QGIS_VERSION "3.42.3-Münster"
+#define VERSION "3.44.0-Solothurn"
+#define _QGIS_VERSION "3.44.0-Solothurn"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 3423
+//#define VERSION_INT 3440
 // TODO QGIS 4: Remove in favor of _QGIS_VERSION_INT
-#define VERSION_INT 34203
-#define _QGIS_VERSION_INT 34203
-#define ABISYM(x) x ## 34203
+#define VERSION_INT 34400
+#define _QGIS_VERSION_INT 34400
+#define ABISYM(x) x ## 34400
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Münster"
+#define RELEASE_NAME "Solothurn"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -42,10 +42,10 @@
 #define QGIS_MACAPP_BUNDLE 
 #endif
 
-#define PYTHON_VERSION "3.13.3"
+#define PYTHON_VERSION "3.13.5"
 #define PYTHON_VERSION_MAJOR "3"
 #define PYTHON_VERSION_MINOR "13"
-#define PYTHON_VERSION_PATCH "3"
+#define PYTHON_VERSION_PATCH "5"
 
 #define PROJ_VERSION_MAJOR 9
 #define PROJ_VERSION_MINOR 6
